import Summary from '~/components/report_cards/chemical_probe/Summary.vue'
import ControlStructuresAndUse from '~/components/report_cards/chemical_probe/ControlStructuresAndUse.vue'
import ProbesForThisCompound from '~/components/report_cards/chemical_probe/ProbesForThisCompound.vue'
import QualityControl from '~/components/report_cards/chemical_probe/QualityControl.vue'
import CompoundActivityProfile from '~/components/report_cards/chemical_probe/CompoundActivityProfile.vue'
import ProbeMechanism from '~/components/report_cards/chemical_probe/ProbeMechanism.vue'
import CompoundCrystalStructures from '~/components/report_cards/chemical_probe/CompoundCrystalStructures.vue'
import CalculatedProperties from '~/components/report_cards/chemical_probe/CalculatedProperties.vue'
import EntityNames from '~/web-components-submodule/standardisation/EntityNames.js'
import CellViabilityAndHealthData from '~/components/report_cards/chemical_probe/CellViabilityAndHealthData.vue'

const methods = {
  generateReportCardStructure(
    itemID,
    prefName,
    isChemicalProbe,
    isNegativeControl,
    showCellHeatlhAndViabilityData
  ) {
    const basePageStructure = [
      {
        id: 'Summary',
        title: 'Summary',
        component: Summary,
        include: true,
      },
      {
        id: 'ProbeMechanism',
        title: 'Mechanism of Action',
        component: ProbeMechanism,
        include: true,
      },
      {
        id: 'ControlStructuresAndUse',
        title: 'Negative Controls',
        component: ControlStructuresAndUse,
        include: isChemicalProbe,
      },
      {
        id: 'ProbesForThisCompound',
        title: 'Related Probes',
        component: ProbesForThisCompound,
        include: isNegativeControl,
      },
      {
        id: 'QualityControl',
        title: 'Quality Control',
        component: QualityControl,
        include: true,
      },
      {
        id: 'ActivityProfile',
        title: 'Activity Profile',
        component: CompoundActivityProfile,
        include: true,
      },
      {
        id: 'CellViabilityAndHealthData',
        title: 'Cell Health Data',
        component: CellViabilityAndHealthData,
        include: showCellHeatlhAndViabilityData,
      },
      {
        id: 'CalculatedProperties',
        title: 'Calculated Properties',
        component: CalculatedProperties,
        componentParams: {
          entityID: EntityNames.EubopenCompound.entityID,
        },
        include: true,
      },
      {
        id: 'CrystalStructures',
        title: 'PDB Ligand Codes',
        component: CompoundCrystalStructures,
        include: true,
      },
    ]

    const finalPageStructure = {
      title: prefName,
      entityName: EntityNames.EubopenCompound.singularEntityName,
      sections: [],
    }

    let index = 0

    for (const section of basePageStructure) {
      if (section.include) {
        section.index = index
        finalPageStructure.sections.push(section)
        index++
      }
    }

    return finalPageStructure
  },
}

export default methods
